@@ -84,7 +84,7 @@
 #define KTEXTEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTEDITOR_NO_DEPRECATED
-#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
 #endif
 #ifdef KTEXTEDITOR_NO_DEPRECATED_WARNINGS
 #  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0x57300
 #  endif
 #endif
 
